==> dataone.common-3.4.0-py3-none-any.whl: d1_common/tests/test_logrecords.py <==
#!/usr/bin/env python

# This work was created by participants in the DataONE project, and is
# jointly copyrighted by participating institutions in DataONE. For
# more information on DataONE, see our web site at http://dataone.org.
#
#   Copyright 2009-2019 DataONE
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import xml.sax

import pyxb

import d1_test.d1_test_case


class TestLogRecords(d1_test.d1_test_case.D1TestCase):
    parameterize_dict = {
        'test_1000': [
            dict(filename='log_gmn_valid.xml', raises_pyxb_exc=False),
            dict(filename='log_knb_valid.xml', raises_pyxb_exc=False),
            dict(filename='log_invalid_1.xml', raises_pyxb_exc=True),
            dict(filename='log_invalid_2.xml', raises_pyxb_exc=True),
            dict(filename='log_invalid_3.xml', raises_pyxb_exc=True),
        ]
    }

    def test_1000(self, filename, raises_pyxb_exc):
        """Deserialize various Log XML docs."""
        try:
            self.test_files.load_xml_to_pyxb(filename)
        except (pyxb.PyXBException, xml.sax.SAXParseException):
            if not raises_pyxb_exc:
                raise

==> dataone.common-3.4.3-py3-none-any.whl: d1_common/tests/test_logrecords.py <==
#!/usr/bin/env python

# This work was created by participants in the DataONE project, and is
# jointly copyrighted by participating institutions in DataONE. For
# more information on DataONE, see our web site at http://dataone.org.
#
#   Copyright 2009-2019 DataONE
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import xml.sax

import pyxb

import d1_test.d1_test_case


class TestLogRecords(d1_test.d1_test_case.D1TestCase):
    parameterize_dict = {
        "test_1000": [
            dict(filename="log_gmn_valid.xml", raises_pyxb_exc=False),
            dict(filename="log_knb_valid.xml", raises_pyxb_exc=False),
            dict(filename="log_invalid_1.xml", raises_pyxb_exc=True),
            dict(filename="log_invalid_2.xml", raises_pyxb_exc=True),
            dict(filename="log_invalid_3.xml", raises_pyxb_exc=True),
        ]
    }

    def test_1000(self, filename, raises_pyxb_exc):
        """Deserialize various Log XML docs."""
        try:
            self.test_files.load_xml_to_pyxb(filename)
        except (pyxb.PyXBException, xml.sax.SAXParseException):
            if not raises_pyxb_exc:
                raise
